@@ -12,7 +12,6 @@ import warnings
 import numpy as np
 import matplotlib as mpl
 
-from matplotlib import cm
 from matplotlib.colors import LightSource
 
 from importlib import import_module
@@ -23,7 +22,7 @@ from mpl_plotter.three_d.components import guides
 from mpl_plotter.three_d.components import framing
 from mpl_plotter.three_d.components import text
 
-from mpl_plotter.three_d.mock import MockData
+from mpl_plotter.three_d.mock import hill
 
 from mpl_plotter.utils import ensure_ndarray
 
@@ -169,7 +168,6 @@ class line(plot):
         :param color: Solid color
         :param cmap: Colormap
         :param alpha: Alpha
-        "param surface_norm: Norm to assign colormap values
 
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
@@ -308,7 +306,6 @@ class scatter(plot):
         :param color: Solid color
         :param cmap: Colormap
         :param alpha: Alpha
-        "param surface_norm: Norm to assign colormap values
 
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
@@ -360,7 +357,7 @@ class surface(plot):
                  # Specifics
                  x=None, y=None, z=None, surface_rstride=1, surface_cstride=1, surface_wire_width=0.1,
                  surface_lighting=False, surface_antialiased=False, surface_shade=False, surface_alpha=1,
-                 surface_cmap_lighting=None, surface_norm=None,
+                 surface_cmap_lighting=None,
                  surface_edge_color='black', surface_edges_to_rgba=False,
                  # Specifics: color
                  cmap='RdBu_r', color=None, color_rule=None,
@@ -452,14 +449,14 @@ class surface(plot):
             Wireframe: alpha=0, line_width>0, surface_edges_to_rgba=False
 
         Specifics
-
+        
         - Surface
         :param x: x
         :param y: y
         :param z: z
         :param surface_rstride: Surface grid definition
         :param surface_cstride: Surface grid definition
-        :param line_width: Width of interpolating lines
+        :param surface_wire_width: Width of interpolating lines
 
         - Lighting
         :param surface_lighting: Apply lighting
@@ -467,13 +464,10 @@ class surface(plot):
         :param surface_shade: Apply shading
 
         - Color
-        :param surface_norm: Instance of matplotlib.colors.Normalize.
-            surface_norm = matplotlib.colors.Normalize(vmin=<vmin>, vmax=<vmax>)
-        :param surface_edge_color: Color of surface plot edges
+        :param surface_edge_color:    Color of surface plot edges
         :param surface_edges_to_rgba: Remove lines from surface plot
-        :param alpha: Transparency
-        :param cmap: Colormap
         :param surface_cmap_lighting: Colormap used for lighting
+        :param surface_alpha:         Transparency
 
         Other
         :param backend: Interactive plotting backends. Working with Python 3.7.6: Qt5Agg, QT4Agg, TkAgg.
@@ -512,35 +506,37 @@ class surface(plot):
         if self.surface_lighting:
             kwargs.update({
                 "cmap":       self.cmap if self.color is None else None,
-                "norm":       self.surface_norm,
+                "norm":       self.cb_norm,
                 "color":      self.color,
                 "facecolors": self.method_lighting()
             })
         elif self.color_rule is not None:
+            positive_color_rule   = self.color_rule - self.color_rule.min()
+            normalized_color_rule = positive_color_rule/positive_color_rule.max()
+            cmap                  = self.cmap if isinstance(self.cmap, mpl.colors.LinearSegmentedColormap) else mpl.colormaps.get_cmap(self.cmap)
+            self.cb_norm          = self.cb_norm if self.cb_norm is not None else mpl.colors.Normalize(vmin=self.color_rule.min(), vmax=self.color_rule.max())
             kwargs.update({
-                "cmap":       mpl.cm.get_cmap(self.cmap) if not isinstance(self.cmap, mpl.colors.LinearSegmentedColormap) else self.cmap,
-                "norm":       self.surface_norm,
-                "facecolors": cmap((self.color_rule + abs(self.color_rule.min()))/(self.color_rule.max() + abs(self.color_rule.min())))
+                "facecolors": cmap(normalized_color_rule),
             })
-        elif self.surface_norm is not None:
-            kwargs.update({
-                "cmap":       self.cmap,
-                "norm":       self.surface_norm
-            })
-        else:
+        elif self.color is not None:
             kwargs.update({
                 "color":      self.color
             })
-
-        self.graph = self.ax.plot_surface(self.x, self.y, self.z, **kwargs)
+        else:
+            self.cb_norm = self.cb_norm if self.cb_norm is not None else mpl.colors.Normalize(vmin=self.z.min(), vmax=self.z.max())
+            kwargs.update({
+                "cmap":       self.cmap,
+                "norm":       self.cb_norm
+            })
             
+        self.graph = self.ax.plot_surface(self.x, self.y, self.z, **kwargs)
+        
         self.method_colorbar()
         self.method_edges_to_rgba()
-
+        
     def mock(self):
         if self.x is None and self.y is None and self.z is None:
-            self.x, self.y, self.z = MockData().hill()
-            self.surface_norm = self.cb_norm = mpl.colors.Normalize(vmin=self.z.min(), vmax=self.z.max())
+            self.x, self.y, self.z = hill()
 
     def method_lighting(self):
         
@@ -568,7 +564,7 @@ class surface(plot):
             cmap = self.surface_cmap_lighting if self.surface_cmap_lighting is not None else self.cmap
             
         rgb = ls.shade(self.z,
-                       cmap=cm.get_cmap(cmap),
+                       cmap=mpl.colormaps.get_cmap(cmap),
                        vert_exag=0.1,
                        blend_mode='soft')
 
