@@ -11,7 +11,7 @@ from tests.setup import show, backend
 class TestAll(unittest.TestCase):
 
     def test_two_d(self):
-        from mpl_plotter.two_d import line, scatter, heatmap, quiver, streamline, fill_area
+        from mpl_plotter.two_d import line, scatter, heatmap, contour, quiver, streamline, fill_area
 
         line(show=show, backend=backend)
         
@@ -19,6 +19,8 @@ class TestAll(unittest.TestCase):
 
         heatmap(show=show, backend=backend)
 
+        contour(show=show, backend=backend)
+
         quiver(show=show, backend=backend)
 
         streamline(show=show, backend=backend)
@@ -27,7 +29,7 @@ class TestAll(unittest.TestCase):
 
         # title
         scatter(show=show, backend=backend,
-                title='A Title including math: $\int_a^bxdx$',
+                title=r'A Title including math: $\int_a^bxdx$',
                 title_pad=20,
                 top=0.815,
                 bottom=0.105,
@@ -37,7 +39,7 @@ class TestAll(unittest.TestCase):
                 wspace=0.2)
 
     def test_two_d_cb(self):
-        from mpl_plotter.two_d import line, scatter, heatmap, quiver, streamline, fill_area
+        from mpl_plotter.two_d import line, scatter, heatmap, contour, quiver, streamline, fill_area
         
         line(show=show, backend=backend,
              color_rule=True,
@@ -52,6 +54,10 @@ class TestAll(unittest.TestCase):
                 colorbar=True,
                 cb_shrink=0.75)
 
+        contour(show=show, backend=backend,
+                colorbar=True,
+                cb_shrink=0.75)
+
         quiver(show=show, backend=backend,
                colorbar=True,
                cb_shrink=0.75)
@@ -127,7 +133,7 @@ class TestAll(unittest.TestCase):
 
         # title
         scatter(show=show, backend=backend,
-                title='A Title including math: $\int_a^bxdx$',
+                title=r'A Title including math: $\int_a^bxdx$',
                 # title_pad=20,
                 top=0.815,
                 bottom=0.105,
@@ -156,23 +162,18 @@ class TestAll(unittest.TestCase):
                 surface_rstride=12)
 
         # solid color
-        x = np.linspace(0, 1, 100)
-        y = np.linspace(0, 1, 100)
-        x, y = np.meshgrid(x, y)
-        z = np.sin(x**2 + y**2)
-        surface(x, y, z,
-                color="orange",
+        surface(color="orange",
                 surface_wire_width=0,
                 surface_lighting=True,
                 show=show, backend=backend)
 
     def test_three_d_cb(self):
         from mpl_plotter.three_d import scatter, surface
-
+        
         scatter(show=show, backend=backend,
                 colorbar=True,
                 cb_shrink=0.65)
-
+        
         surface(show=show, backend=backend,
                 colorbar=True,
                 cb_shrink=0.65)
